"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockProcessorRegistry = void 0;
const textBlockProcessor_1 = require("./textBlockProcessor");
const imageBlockProcessor_1 = require("./imageBlockProcessor");
const mediaBlockProcessor_1 = require("./mediaBlockProcessor");
const structureBlockProcessor_1 = require("./structureBlockProcessor");
class BlockProcessorRegistry {
    processors = [];
    context;
    constructor(context) {
        this.context = context;
        this.registerDefaultProcessors();
    }
    registerDefaultProcessors() {
        // 기본 프로세서 등록
        this.registerProcessor(new textBlockProcessor_1.TextBlockProcessor(this.context));
        this.registerProcessor(new imageBlockProcessor_1.ImageBlockProcessor(this.context));
        this.registerProcessor(new mediaBlockProcessor_1.MediaBlockProcessor(this.context));
        this.registerProcessor(new structureBlockProcessor_1.StructureBlockProcessor(this.context));
    }
    registerProcessor(processor) {
        this.processors.push(processor);
    }
    async processBlock(block) {
        for (const processor of this.processors) {
            if (processor.canProcess(block)) {
                return await processor.process(block);
            }
        }
        // 어떤 프로세서도 처리할 수 없는 경우 (디버깅을 위해 타입 로그)
        this.context.reporter.warn(`Unsupported block type: ${block.type}`);
        // 기본 결과 반환
        return {
            updatedBlock: block,
            plainText: "",
        };
    }
}
exports.BlockProcessorRegistry = BlockProcessorRegistry;
